API
===

This is the API documentation for the `eyelinkio` package, grouped thematically
by functionality. we use ``snake_case`` for function names and ``CamelCase``
for class names.

Reading EDF files
-----------------

.. automodule:: eyelinkio.edf.read_edf
   :members:
   :exclude-members: EDF


``EDF`` class
-------------

.. autoclass:: eyelinkio.EDF
   :members:
